@@ -1,7 +1,9 @@
 package Module::Abstract::Cwalitee;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-06-06'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DIST = 'Module-Abstract-Cwalitee'; # DIST
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -101,7 +103,7 @@ Module::Abstract::Cwalitee - Calculate the cwalitee of your module Abstract
 
 =head1 VERSION
 
-This document describes version 0.007 of Module::Abstract::Cwalitee (from Perl distribution Module-Abstract-Cwalitee), released on 2021-06-06.
+This document describes version 0.008 of Module::Abstract::Cwalitee (from Perl distribution Module-Abstract-Cwalitee), released on 2021-06-06.
 
 =head1 SYNOPSIS
 
@@ -231,7 +233,7 @@ Result:
        result_summary => "11 out of 11",
      },
    ],
-   {},
+   { "func.score" => "100.00", "func.score_summary" => "11 out of 11" },
  ]
 
 =item * Example of a not-so-good Abstract:
@@ -323,7 +325,7 @@ Result:
      },
      { indicator => "Score", result => 81.82, result_summary => "9 out of 11" },
    ],
-   {},
+   { "func.score" => 81.82, "func.score_summary" => "9 out of 11" },
  ]
 
 =back
